@@ -4,8 +4,8 @@
 from __future__ import annotations
 
 import heapq
+import numbers
 from contextlib import suppress
-from math import isnan
 from typing import (
     Any,
     Callable,
@@ -17,7 +17,7 @@ from typing import (
     overload,
 )
 
-from rapidfuzz._utils import ScorerFlag
+from rapidfuzz._utils import ScorerFlag, is_none
 from rapidfuzz.fuzz import WRatio, ratio
 
 __all__ = ["extract", "extract_iter", "extractOne", "cdist"]
@@ -31,16 +31,6 @@ def _get_scorer_flags_py(scorer: Any, scorer_kwargs: dict[str, Any]) -> tuple[in
     return (0, 100)
 
 
-def _is_none(s: Any) -> bool:
-    if s is None:
-        return True
-
-    if isinstance(s, float) and isnan(s):
-        return True
-
-    return False
-
-
 @overload
 def extract_iter(
     query: Sequence[Hashable] | None,
@@ -51,8 +41,7 @@ def extract_iter(
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
     scorer_kwargs: dict[str, Any] | None = None,
-) -> Iterable[tuple[Sequence[Hashable], int | float, int]]:
-    ...
+) -> Iterable[tuple[Sequence[Hashable], int | float, int]]: ...
 
 
 @overload
@@ -65,8 +54,7 @@ def extract_iter(
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
     scorer_kwargs: dict[str, Any] | None = None,
-) -> Iterable[tuple[Sequence[Hashable], int | float, Any]]:
-    ...
+) -> Iterable[tuple[Sequence[Hashable], int | float, Any]]: ...
 
 
 def extract_iter(
@@ -141,7 +129,7 @@ def extract_iter(
     worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
-    if _is_none(query):
+    if is_none(query):
         return
 
     if score_cutoff is None:
@@ -154,7 +142,7 @@ def extract_iter(
     choices_iter: Iterable[tuple[Any, Sequence[Hashable] | None]]
     choices_iter = choices.items() if hasattr(choices, "items") else enumerate(choices)  # type: ignore[union-attr]
     for key, choice in choices_iter:
-        if _is_none(choice):
+        if is_none(choice):
             continue
 
         if processor is None:
@@ -185,8 +173,7 @@ def extractOne(
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
     scorer_kwargs: dict[str, Any] | None = None,
-) -> tuple[Sequence[Hashable], int | float, int] | None:
-    ...
+) -> tuple[Sequence[Hashable], int | float, int] | None: ...
 
 
 @overload
@@ -199,8 +186,7 @@ def extractOne(
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
     scorer_kwargs: dict[str, Any] | None = None,
-) -> tuple[Sequence[Hashable], int | float, Any] | None:
-    ...
+) -> tuple[Sequence[Hashable], int | float, Any] | None: ...
 
 
 def extractOne(
@@ -334,7 +320,7 @@ def extractOne(
     worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
-    if _is_none(query):
+    if is_none(query):
         return None
 
     if score_cutoff is None:
@@ -349,7 +335,7 @@ def extractOne(
     choices_iter: Iterable[tuple[Any, Sequence[Hashable] | None]]
     choices_iter = choices.items() if hasattr(choices, "items") else enumerate(choices)  # type: ignore[union-attr]
     for key, choice in choices_iter:
-        if _is_none(choice):
+        if is_none(choice):
             continue
 
         if processor is None:
@@ -388,8 +374,7 @@ def extract(
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
     scorer_kwargs: dict[str, Any] | None = None,
-) -> list[tuple[Sequence[Hashable], int | float, int]]:
-    ...
+) -> list[tuple[Sequence[Hashable], int | float, int]]: ...
 
 
 @overload
@@ -403,8 +388,7 @@ def extract(
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
     scorer_kwargs: dict[str, Any] | None = None,
-) -> list[tuple[Sequence[Hashable], int | float, Any]]:
-    ...
+) -> list[tuple[Sequence[Hashable], int | float, Any]]: ...
 
 
 def extract(
@@ -486,6 +470,20 @@ def extract(
     worst_score, optimal_score = _get_scorer_flags_py(scorer, scorer_kwargs)
     lowest_score_worst = optimal_score > worst_score
 
+    if limit == 1:
+        res = extractOne(
+            query,
+            choices,
+            processor=processor,
+            scorer=scorer,
+            score_cutoff=score_cutoff,
+            score_hint=score_hint,
+            scorer_kwargs=scorer_kwargs,
+        )
+        if res is None:
+            return []
+        return [res]
+
     result_iter = extract_iter(
         query,
         choices,
@@ -523,6 +521,8 @@ def _dtype_to_type_num(
         flags = params["get_scorer_flags"](**scorer_kwargs)
         if flags["flags"] & ScorerFlag.RESULT_I64:
             return np.int32
+        if flags["flags"] & ScorerFlag.RESULT_SIZE_T:
+            return np.uint32
         return np.float32
 
     return np.float32
@@ -546,6 +546,7 @@ def cdist(
     processor: Callable[..., Sequence[Hashable]] | None = None,
     score_cutoff: int | float | None = None,
     score_hint: int | float | None = None,
+    score_multiplier: int | float = 1,
     dtype: np.dtype | None = None,
     workers: int = 1,
     scorer_kwargs: dict[str, Any] | None = None,
@@ -575,6 +576,11 @@ def cdist(
         Optional argument for an expected score to be passed to the scorer.
         This is used to select a faster implementation. Default is None,
         which deactivates this behaviour.
+    score_multiplier: Any, optional
+        Optional argument to multiply the calculated score with. This is applied as the final step,
+        so e.g. score_cutoff is applied on the unmodified score. This is mostly useful to map from
+        a floating point range to an integer to reduce the memory usage. Default is 1,
+        which deactivates this behaviour.
     dtype : data-type, optional
         The desired data-type for the result array.Depending on the scorer type the following
         dtypes are supported:
@@ -611,27 +617,48 @@ def cdist(
     if processor is None:
         proc_choices = list(choices)
     else:
-        proc_choices = [x if _is_none(x) else processor(x) for x in choices]
+        proc_choices = [x if is_none(x) else processor(x) for x in choices]
 
     if queries is choices and _is_symmetric(scorer, scorer_kwargs):
         for i, query in enumerate(proc_choices):
-            results[i, i] = scorer(query, query, score_cutoff=score_cutoff, **scorer_kwargs)
+            score = scorer(query, query, score_cutoff=score_cutoff, **scorer_kwargs) * score_multiplier
+
+            if issubclass(dtype, numbers.Integral):
+                score = round(score)
+
+            results[i, i] = score
             for j in range(i + 1, len(proc_choices)):
-                results[i, j] = results[j, i] = scorer(
-                    query,
-                    proc_choices[j],
-                    score_cutoff=score_cutoff,
-                    **scorer_kwargs,
-                )
-    else:
-        for i, query in enumerate(queries):
-            proc_query = processor(query) if (processor and not _is_none(query)) else query
-            for j, choice in enumerate(proc_choices):
-                results[i, j] = scorer(
-                    proc_query,
-                    choice,
-                    score_cutoff=score_cutoff,
-                    **scorer_kwargs,
+                score = (
+                    scorer(
+                        query,
+                        proc_choices[j],
+                        score_cutoff=score_cutoff,
+                        **scorer_kwargs,
+                    )
+                    * score_multiplier
                 )
 
+                if issubclass(dtype, numbers.Integral):
+                    score = round(score)
+
+                results[i, j] = results[j, i] = score
+    else:
+        for i, query in enumerate(queries):
+            proc_query = processor(query) if (processor and not is_none(query)) else query
+            for j, choice in enumerate(proc_choices):
+                score = (
+                    scorer(
+                        proc_query,
+                        choice,
+                        score_cutoff=score_cutoff,
+                        **scorer_kwargs,
+                    )
+                    * score_multiplier
+                )
+
+                if issubclass(dtype, numbers.Integral):
+                    score = round(score)
+
+                results[i, j] = score
+
     return results
